@@ -22,11 +22,11 @@
 # define CONFLICTS_H_
 # include "state.h"
 
-void conflicts_solve PARAMS ((void));
-void conflicts_print PARAMS ((void));
-int conflicts_total_count PARAMS ((void));
-void conflicts_output PARAMS ((FILE *out));
-void conflicts_free PARAMS ((void));
+void conflicts_solve (void);
+void conflicts_print (void);
+int conflicts_total_count (void);
+void conflicts_output (FILE *out);
+void conflicts_free (void);
 
 /* Were there conflicts? */
 extern int expected_conflicts;
