@@ -1,5 +1,5 @@
 /* Output the generated parsing program for bison,
-   Copyright 2000 Free Software Foundation, Inc.
+   Copyright (C) 2000, 2001, 2002  Free Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -21,13 +21,9 @@
 #ifndef OUTPUT_H_
 # define OUTPUT_H_
 
-/* Output constant strings to the beginning of certain files.  */
-void output_headers PARAMS ((void));
-
-/* Output constant strings to the ends of certain files.  */
-void output_trailers PARAMS ((void));
+extern int error_verbose;
 
 /* Output the parsing tables and the parser code to FTABLE.  */
-void output PARAMS ((void));
+void output (void);
 
 #endif /* !OUTPUT_H_ */
