@@ -21,6 +21,6 @@
 #ifndef PRINT_H_
 # define PRINT_H_
 
-void print_results PARAMS ((void));
+void print_results (void);
 
 #endif /* !PRINT_H_ */
